# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/technologies/keyword_spotting/v1/keyword_spotting.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'phonexia/grpc/technologies/keyword_spotting/v1/keyword_spotting.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from phonexia.grpc.common import core_pb2 as phonexia_dot_grpc_dot_common_dot_core__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEphonexia/grpc/technologies/keyword_spotting/v1/keyword_spotting.proto\x12.phonexia.grpc.technologies.keyword_spotting.v1\x1a\x1fphonexia/grpc/common/core.proto\x1a\x1egoogle/protobuf/duration.proto\"3\n\x07Keyword\x12\x10\n\x08spelling\x18\x01 \x01(\t\x12\x16\n\x0epronunciations\x18\x02 \x03(\t\"\xd4\x01\n\rDetectRequest\x12*\n\x05\x61udio\x18\x01 \x01(\x0b\x32\x1b.phonexia.grpc.common.Audio\x12I\n\x08keywords\x18\x02 \x03(\x0b\x32\x37.phonexia.grpc.technologies.keyword_spotting.v1.Keyword\x12L\n\x06\x63onfig\x18\x03 \x01(\x0b\x32<.phonexia.grpc.technologies.keyword_spotting.v1.DetectConfig\"J\n\x0c\x44\x65tectConfig\x12!\n\x14\x63onfidence_sharpness\x18\x01 \x01(\x02H\x00\x88\x01\x01\x42\x17\n\x15_confidence_sharpness\"\x81\x02\n\x0eMatchedKeyword\x12\x10\n\x08spelling\x18\x01 \x01(\t\x12\x15\n\rpronunciation\x18\x02 \x01(\t\x12p\n\x14pronunciation_source\x18\x03 \x01(\x0e\x32R.phonexia.grpc.technologies.keyword_spotting.v1.MatchedKeyword.PronunciationSource\"T\n\x13PronunciationSource\x12\x0e\n\nDICTIONARY\x10\x00\x12\r\n\tGENERATED\x10\x01\x12\x08\n\x04USER\x10\x02\x12\x14\n\x10PARTLY_GENERATED\x10\x03\"\xd7\x01\n\x05Match\x12-\n\nstart_time\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x12\n\nconfidence\x18\x03 \x01(\x02\x12\r\n\x05score\x18\x04 \x01(\x02\x12O\n\x07keyword\x18\x05 \x01(\x0b\x32>.phonexia.grpc.technologies.keyword_spotting.v1.MatchedKeyword\"V\n\x0c\x44\x65tectResult\x12\x46\n\x07matches\x18\x01 \x03(\x0b\x32\x35.phonexia.grpc.technologies.keyword_spotting.v1.Match\"\x99\x01\n\x0e\x44\x65tectResponse\x12L\n\x06result\x18\x01 \x01(\x0b\x32<.phonexia.grpc.technologies.keyword_spotting.v1.DetectResult\x12\x39\n\x16processed_audio_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"\x1b\n\x19ListAllowedSymbolsRequest\"A\n\x1aListAllowedSymbolsResponse\x12\x11\n\tgraphemes\x18\x01 \x03(\t\x12\x10\n\x08phonemes\x18\x02 \x03(\t2\xcd\x02\n\x0fKeywordSpotting\x12\x8b\x01\n\x06\x44\x65tect\x12=.phonexia.grpc.technologies.keyword_spotting.v1.DetectRequest\x1a>.phonexia.grpc.technologies.keyword_spotting.v1.DetectResponse(\x01\x30\x01\x12\xab\x01\n\x12ListAllowedSymbols\x12I.phonexia.grpc.technologies.keyword_spotting.v1.ListAllowedSymbolsRequest\x1aJ.phonexia.grpc.technologies.keyword_spotting.v1.ListAllowedSymbolsResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.technologies.keyword_spotting.v1.keyword_spotting_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_KEYWORD']._serialized_start=186
  _globals['_KEYWORD']._serialized_end=237
  _globals['_DETECTREQUEST']._serialized_start=240
  _globals['_DETECTREQUEST']._serialized_end=452
  _globals['_DETECTCONFIG']._serialized_start=454
  _globals['_DETECTCONFIG']._serialized_end=528
  _globals['_MATCHEDKEYWORD']._serialized_start=531
  _globals['_MATCHEDKEYWORD']._serialized_end=788
  _globals['_MATCHEDKEYWORD_PRONUNCIATIONSOURCE']._serialized_start=704
  _globals['_MATCHEDKEYWORD_PRONUNCIATIONSOURCE']._serialized_end=788
  _globals['_MATCH']._serialized_start=791
  _globals['_MATCH']._serialized_end=1006
  _globals['_DETECTRESULT']._serialized_start=1008
  _globals['_DETECTRESULT']._serialized_end=1094
  _globals['_DETECTRESPONSE']._serialized_start=1097
  _globals['_DETECTRESPONSE']._serialized_end=1250
  _globals['_LISTALLOWEDSYMBOLSREQUEST']._serialized_start=1252
  _globals['_LISTALLOWEDSYMBOLSREQUEST']._serialized_end=1279
  _globals['_LISTALLOWEDSYMBOLSRESPONSE']._serialized_start=1281
  _globals['_LISTALLOWEDSYMBOLSRESPONSE']._serialized_end=1346
  _globals['_KEYWORDSPOTTING']._serialized_start=1349
  _globals['_KEYWORDSPOTTING']._serialized_end=1682
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/technologies/speech_to_text/v1/speech_to_text.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'phonexia/grpc/technologies/speech_to_text/v1/speech_to_text.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from phonexia.grpc.common import core_pb2 as phonexia_dot_grpc_dot_common_dot_core__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAphonexia/grpc/technologies/speech_to_text/v1/speech_to_text.proto\x12,phonexia.grpc.technologies.speech_to_text.v1\x1a\x1fphonexia/grpc/common/core.proto\x1a\x1egoogle/protobuf/duration.proto\"\x9f\x01\n\x11TranscribeRequest\x12*\n\x05\x61udio\x18\x01 \x01(\x0b\x32\x1b.phonexia.grpc.common.Audio\x12S\n\x06\x63onfig\x18\x02 \x01(\x0b\x32>.phonexia.grpc.technologies.speech_to_text.v1.TranscribeConfigH\x00\x88\x01\x01\x42\t\n\x07_config\"\xde\x01\n\x10TranscribeConfig\x12\x19\n\x11preferred_phrases\x18\x01 \x03(\t\x12_\n\x10\x61\x64\x64itional_words\x18\x02 \x03(\x0b\x32\x45.phonexia.grpc.technologies.speech_to_text.v1.RequestedAdditionalWord\x12N\n\x0cresult_types\x18\x03 \x03(\x0e\x32\x38.phonexia.grpc.technologies.speech_to_text.v1.ResultType\"C\n\x17RequestedAdditionalWord\x12\x10\n\x08spelling\x18\x01 \x01(\t\x12\x16\n\x0epronunciations\x18\x02 \x03(\t\"\xb6\x01\n\x04Word\x12\x0c\n\x04text\x18\x01 \x01(\t\x12-\n\nstart_time\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x44\n\x04type\x18\x04 \x01(\x0e\x32\x36.phonexia.grpc.technologies.speech_to_text.v1.ItemType\"\xbd\x01\n\x0eOneBestSegment\x12\x0c\n\x04text\x18\x01 \x01(\t\x12-\n\nstart_time\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x41\n\x05words\x18\x04 \x03(\x0b\x32\x32.phonexia.grpc.technologies.speech_to_text.v1.Word\"Y\n\x07OneBest\x12N\n\x08segments\x18\x01 \x03(\x0b\x32<.phonexia.grpc.technologies.speech_to_text.v1.OneBestSegment\"\x97\x01\n\x17NBestSegmentAlternative\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x12\n\nconfidence\x18\x02 \x01(\x02\x12-\n\nstart_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08\x65nd_time\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\"s\n\x0cNBestSegment\x12\x63\n\x14segment_alternatives\x18\x01 \x03(\x0b\x32\x45.phonexia.grpc.technologies.speech_to_text.v1.NBestSegmentAlternative\"U\n\x05NBest\x12L\n\x08segments\x18\x01 \x03(\x0b\x32:.phonexia.grpc.technologies.speech_to_text.v1.NBestSegment\"\xe5\x01\n\x1f\x43onfusionNetworkWordAlternative\x12\x0c\n\x04text\x18\x01 \x01(\t\x12-\n\nstart_time\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x12\n\nconfidence\x18\x04 \x01(\x02\x12\x44\n\x04type\x18\x05 \x01(\x0e\x32\x36.phonexia.grpc.technologies.speech_to_text.v1.ItemType\"\x80\x01\n\x14\x43onfusionNetworkWord\x12h\n\x11word_alternatives\x18\x01 \x03(\x0b\x32M.phonexia.grpc.technologies.speech_to_text.v1.ConfusionNetworkWordAlternative\"e\n\x10\x43onfusionNetwork\x12Q\n\x05words\x18\x01 \x03(\x0b\x32\x42.phonexia.grpc.technologies.speech_to_text.v1.ConfusionNetworkWord\"\xab\x03\n\x10TranscribeResult\x12L\n\x08one_best\x18\x01 \x01(\x0b\x32\x35.phonexia.grpc.technologies.speech_to_text.v1.OneBestH\x00\x88\x01\x01\x12H\n\x06n_best\x18\x02 \x01(\x0b\x32\x33.phonexia.grpc.technologies.speech_to_text.v1.NBestH\x01\x88\x01\x01\x12^\n\x11\x63onfusion_network\x18\x03 \x01(\x0b\x32>.phonexia.grpc.technologies.speech_to_text.v1.ConfusionNetworkH\x02\x88\x01\x01\x12_\n\x10\x61\x64\x64itional_words\x18\x04 \x03(\x0b\x32\x45.phonexia.grpc.technologies.speech_to_text.v1.ResultingAdditionalWord\x12\x10\n\x08language\x18\x05 \x01(\tB\x0b\n\t_one_bestB\t\n\x07_n_bestB\x14\n\x12_confusion_network\"\x89\x01\n\x17ResultingAdditionalWord\x12\x10\n\x08spelling\x18\x01 \x01(\t\x12\\\n\x0epronunciations\x18\x02 \x03(\x0b\x32\x44.phonexia.grpc.technologies.speech_to_text.v1.ResultingPronunciation\"J\n\x16ResultingPronunciation\x12\x15\n\rpronunciation\x18\x01 \x01(\t\x12\x19\n\x11out_of_vocabulary\x18\x02 \x01(\x08\"\x9f\x01\n\x12TranscribeResponse\x12N\n\x06result\x18\x01 \x01(\x0b\x32>.phonexia.grpc.technologies.speech_to_text.v1.TranscribeResult\x12\x39\n\x16processed_audio_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"\x1b\n\x19ListAllowedSymbolsRequest\"Y\n\x1aListAllowedSymbolsResponse\x12\x11\n\tgraphemes\x18\x01 \x03(\t\x12\x10\n\x08phonemes\x18\x02 \x03(\t\x12\x16\n\x0eword_separator\x18\x03 \x01(\t*a\n\nResultType\x12\x18\n\x14RESULT_TYPE_ONE_BEST\x10\x00\x12\x16\n\x12RESULT_TYPE_N_BEST\x10\x01\x12!\n\x1dRESULT_TYPE_CONFUSION_NETWORK\x10\x02*\x81\x01\n\x08ItemType\x12\x12\n\x0eITEM_TYPE_WORD\x10\x00\x12\x15\n\x11ITEM_TYPE_SILENCE\x10\x01\x12\x1b\n\x17ITEM_TYPE_SEGMENT_START\x10\x02\x12\x19\n\x15ITEM_TYPE_SEGMENT_END\x10\x03\x12\x12\n\x0eITEM_TYPE_NULL\x10\x04\x32\xce\x02\n\x0cSpeechToText\x12\x93\x01\n\nTranscribe\x12?.phonexia.grpc.technologies.speech_to_text.v1.TranscribeRequest\x1a@.phonexia.grpc.technologies.speech_to_text.v1.TranscribeResponse(\x01\x30\x01\x12\xa7\x01\n\x12ListAllowedSymbols\x12G.phonexia.grpc.technologies.speech_to_text.v1.ListAllowedSymbolsRequest\x1aH.phonexia.grpc.technologies.speech_to_text.v1.ListAllowedSymbolsResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.technologies.speech_to_text.v1.speech_to_text_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_RESULTTYPE']._serialized_start=2856
  _globals['_RESULTTYPE']._serialized_end=2953
  _globals['_ITEMTYPE']._serialized_start=2956
  _globals['_ITEMTYPE']._serialized_end=3085
  _globals['_TRANSCRIBEREQUEST']._serialized_start=181
  _globals['_TRANSCRIBEREQUEST']._serialized_end=340
  _globals['_TRANSCRIBECONFIG']._serialized_start=343
  _globals['_TRANSCRIBECONFIG']._serialized_end=565
  _globals['_REQUESTEDADDITIONALWORD']._serialized_start=567
  _globals['_REQUESTEDADDITIONALWORD']._serialized_end=634
  _globals['_WORD']._serialized_start=637
  _globals['_WORD']._serialized_end=819
  _globals['_ONEBESTSEGMENT']._serialized_start=822
  _globals['_ONEBESTSEGMENT']._serialized_end=1011
  _globals['_ONEBEST']._serialized_start=1013
  _globals['_ONEBEST']._serialized_end=1102
  _globals['_NBESTSEGMENTALTERNATIVE']._serialized_start=1105
  _globals['_NBESTSEGMENTALTERNATIVE']._serialized_end=1256
  _globals['_NBESTSEGMENT']._serialized_start=1258
  _globals['_NBESTSEGMENT']._serialized_end=1373
  _globals['_NBEST']._serialized_start=1375
  _globals['_NBEST']._serialized_end=1460
  _globals['_CONFUSIONNETWORKWORDALTERNATIVE']._serialized_start=1463
  _globals['_CONFUSIONNETWORKWORDALTERNATIVE']._serialized_end=1692
  _globals['_CONFUSIONNETWORKWORD']._serialized_start=1695
  _globals['_CONFUSIONNETWORKWORD']._serialized_end=1823
  _globals['_CONFUSIONNETWORK']._serialized_start=1825
  _globals['_CONFUSIONNETWORK']._serialized_end=1926
  _globals['_TRANSCRIBERESULT']._serialized_start=1929
  _globals['_TRANSCRIBERESULT']._serialized_end=2356
  _globals['_RESULTINGADDITIONALWORD']._serialized_start=2359
  _globals['_RESULTINGADDITIONALWORD']._serialized_end=2496
  _globals['_RESULTINGPRONUNCIATION']._serialized_start=2498
  _globals['_RESULTINGPRONUNCIATION']._serialized_end=2572
  _globals['_TRANSCRIBERESPONSE']._serialized_start=2575
  _globals['_TRANSCRIBERESPONSE']._serialized_end=2734
  _globals['_LISTALLOWEDSYMBOLSREQUEST']._serialized_start=2736
  _globals['_LISTALLOWEDSYMBOLSREQUEST']._serialized_end=2763
  _globals['_LISTALLOWEDSYMBOLSRESPONSE']._serialized_start=2765
  _globals['_LISTALLOWEDSYMBOLSRESPONSE']._serialized_end=2854
  _globals['_SPEECHTOTEXT']._serialized_start=3088
  _globals['_SPEECHTOTEXT']._serialized_end=3422
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2025 Phonexia s.r.o.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Health check definitions for gRPC API.
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class HealthCheckRequest(google.protobuf.message.Message):
    """Request message for checking the health of a service."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_FIELD_NUMBER: builtins.int
    service: builtins.str
    """The name of the service to check."""
    def __init__(
        self,
        *,
        service: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["service", b"service"]) -> None: ...

Global___HealthCheckRequest: typing_extensions.TypeAlias = HealthCheckRequest

@typing.final
class HealthCheckResponse(google.protobuf.message.Message):
    """Response message for checking the health of a service."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ServingStatus:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ServingStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[HealthCheckResponse._ServingStatus.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: HealthCheckResponse._ServingStatus.ValueType  # 0
        """The serving status is unknown."""
        SERVING: HealthCheckResponse._ServingStatus.ValueType  # 1
        """The service is serving requests."""
        NOT_SERVING: HealthCheckResponse._ServingStatus.ValueType  # 2
        """The service is not serving requests."""

    class ServingStatus(_ServingStatus, metaclass=_ServingStatusEnumTypeWrapper):
        """The serving status of the checked service."""

    UNKNOWN: HealthCheckResponse.ServingStatus.ValueType  # 0
    """The serving status is unknown."""
    SERVING: HealthCheckResponse.ServingStatus.ValueType  # 1
    """The service is serving requests."""
    NOT_SERVING: HealthCheckResponse.ServingStatus.ValueType  # 2
    """The service is not serving requests."""

    STATUS_FIELD_NUMBER: builtins.int
    status: Global___HealthCheckResponse.ServingStatus.ValueType
    """The serving status of the checked service."""
    def __init__(
        self,
        *,
        status: Global___HealthCheckResponse.ServingStatus.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

Global___HealthCheckResponse: typing_extensions.TypeAlias = HealthCheckResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2025 Phonexia s.r.o.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Phonexia Audio Denoiser gRPC API.
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.message
import phonexia.grpc.common.core_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class DenoiseRequest(google.protobuf.message.Message):
    """The top-level message sent by the client for the <code>Denoise</code> method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIO_FIELD_NUMBER: builtins.int
    @property
    def audio(self) -> phonexia.grpc.common.core_pb2.Audio:
        """Audio data to denoise. There is no minimum audio length limit."""

    def __init__(
        self,
        *,
        audio: phonexia.grpc.common.core_pb2.Audio | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["audio", b"audio"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["audio", b"audio"]) -> None: ...

Global___DenoiseRequest: typing_extensions.TypeAlias = DenoiseRequest

@typing.final
class DenoiseResponse(google.protobuf.message.Message):
    """The top-level message returned to the client by the <code>Denoise</code> method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULT_FIELD_NUMBER: builtins.int
    PROCESSED_AUDIO_LENGTH_FIELD_NUMBER: builtins.int
    @property
    def result(self) -> Global___DenoiseResult:
        """Result containing the denoised audio."""

    @property
    def processed_audio_length(self) -> google.protobuf.duration_pb2.Duration:
        """Total length of the processed audio."""

    def __init__(
        self,
        *,
        result: Global___DenoiseResult | None = ...,
        processed_audio_length: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["processed_audio_length", b"processed_audio_length", "result", b"result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["processed_audio_length", b"processed_audio_length", "result", b"result"]) -> None: ...

Global___DenoiseResponse: typing_extensions.TypeAlias = DenoiseResponse

@typing.final
class DenoiseResult(google.protobuf.message.Message):
    """Message containing the result of audio denoising."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIO_FIELD_NUMBER: builtins.int
    @property
    def audio(self) -> phonexia.grpc.common.core_pb2.Audio:
        """Denoised audio. Sample rate is the same as the input audio sample rate.
        If the input was an audio with header, the result will also be audio
        with header. If the input was sent in raw format, the result will also
        be in a header-less raw format.
        """

    def __init__(
        self,
        *,
        audio: phonexia.grpc.common.core_pb2.Audio | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["audio", b"audio"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["audio", b"audio"]) -> None: ...

Global___DenoiseResult: typing_extensions.TypeAlias = DenoiseResult



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2025 Phonexia s.r.o.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Phonexia Time Analysis gRPC API.
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import phonexia.grpc.common.core_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class AnalyzeRequest(google.protobuf.message.Message):
    """The top-level message sent by the client for the <code>Analyze</code>
    method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIO_FIELD_NUMBER: builtins.int
    @property
    def audio(self) -> phonexia.grpc.common.core_pb2.Audio:
        """Audio data for which Time Analysis should be performed.
        Audio can be either mono or stereo. In case of mono, only the ChannelAnalysis
        message is returned. At least 900 milliseconds of audio is required, otherwise
        the result will not contain any analyses.
        """

    def __init__(
        self,
        *,
        audio: phonexia.grpc.common.core_pb2.Audio | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["audio", b"audio"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["audio", b"audio"]) -> None: ...

Global___AnalyzeRequest: typing_extensions.TypeAlias = AnalyzeRequest

@typing.final
class ReactionAnalysis(google.protobuf.message.Message):
    """Time Analysis of how an individual channel reacts to the other channel."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REACTING_CHANNEL_FIELD_NUMBER: builtins.int
    REACTIONS_COUNT_FIELD_NUMBER: builtins.int
    AVERAGE_REACTION_TIME_FIELD_NUMBER: builtins.int
    FASTEST_REACTION_POSITION_FIELD_NUMBER: builtins.int
    SLOWEST_REACTION_POSITION_FIELD_NUMBER: builtins.int
    CROSSTALKS_FIELD_NUMBER: builtins.int
    reacting_channel: builtins.int
    """Index of the channel whose reactions are analyzed."""
    reactions_count: builtins.int
    """Number of reactions of this channel to the other channel. A "reaction" is defined
    as the act when the speaker in the reacting channel starts speaking AFTER the
    speaker in the other channel has stopped speaking.
    """
    @property
    def average_reaction_time(self) -> google.protobuf.duration_pb2.Duration:
        """Average time that elapsed between the speaker in the other channel stopped speaking
        and the speaker in the reacting channel started speaking.
        When no reaction to the other channel was detected, this field is set to 0.
        """

    @property
    def fastest_reaction_position(self) -> phonexia.grpc.common.core_pb2.TimeRange:
        """Position of this channel's fastest reaction (shortest reaction time).
        When no reaction to the other channel was detected, this field is set to 0.
        """

    @property
    def slowest_reaction_position(self) -> phonexia.grpc.common.core_pb2.TimeRange:
        """Position of this channel's slowest reaction (longest reaction time).
        When no reaction to the other channel was detected, this field is set to 0.
        """

    @property
    def crosstalks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[phonexia.grpc.common.core_pb2.TimeRange]:
        """List of positions of this channel's crosstalks. A "crosstalk" is defined as the act
        when the speaker in the reacting channel starts speaking WHILE the speaker in the
        other channel is still speaking. The crosstalk lasts as long as both speakers are
        speaking.
        """

    def __init__(
        self,
        *,
        reacting_channel: builtins.int = ...,
        reactions_count: builtins.int = ...,
        average_reaction_time: google.protobuf.duration_pb2.Duration | None = ...,
        fastest_reaction_position: phonexia.grpc.common.core_pb2.TimeRange | None = ...,
        slowest_reaction_position: phonexia.grpc.common.core_pb2.TimeRange | None = ...,
        crosstalks: collections.abc.Iterable[phonexia.grpc.common.core_pb2.TimeRange] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["average_reaction_time", b"average_reaction_time", "fastest_reaction_position", b"fastest_reaction_position", "slowest_reaction_position", b"slowest_reaction_position"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["average_reaction_time", b"average_reaction_time", "crosstalks", b"crosstalks", "fastest_reaction_position", b"fastest_reaction_position", "reacting_channel", b"reacting_channel", "reactions_count", b"reactions_count", "slowest_reaction_position", b"slowest_reaction_position"]) -> None: ...

Global___ReactionAnalysis: typing_extensions.TypeAlias = ReactionAnalysis

@typing.final
class ChannelAnalysis(google.protobuf.message.Message):
    """Time Analysis for an individual channel."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_NUMBER_FIELD_NUMBER: builtins.int
    SPEECH_LENGTH_FIELD_NUMBER: builtins.int
    SPEECH_RATE_FIELD_NUMBER: builtins.int
    TOTAL_LENGTH_FIELD_NUMBER: builtins.int
    channel_number: builtins.int
    """Index of the channel."""
    speech_rate: builtins.float
    """Speech rate as the number of phonemes per second."""
    @property
    def speech_length(self) -> google.protobuf.duration_pb2.Duration:
        """Length of speech in this channel."""

    @property
    def total_length(self) -> google.protobuf.duration_pb2.Duration:
        """Length of audio in this channel."""

    def __init__(
        self,
        *,
        channel_number: builtins.int = ...,
        speech_length: google.protobuf.duration_pb2.Duration | None = ...,
        speech_rate: builtins.float | None = ...,
        total_length: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_speech_rate", b"_speech_rate", "speech_length", b"speech_length", "speech_rate", b"speech_rate", "total_length", b"total_length"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_speech_rate", b"_speech_rate", "channel_number", b"channel_number", "speech_length", b"speech_length", "speech_rate", b"speech_rate", "total_length", b"total_length"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["_speech_rate", b"_speech_rate"]) -> typing.Literal["speech_rate"] | None: ...

Global___ChannelAnalysis: typing_extensions.TypeAlias = ChannelAnalysis

@typing.final
class AnalyzeResult(google.protobuf.message.Message):
    """The collection of all Time Analysis result types."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ANALYSES_FIELD_NUMBER: builtins.int
    REACTION_ANALYSES_FIELD_NUMBER: builtins.int
    @property
    def channel_analyses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___ChannelAnalysis]:
        """List of Time Analyses for individual channels."""

    @property
    def reaction_analyses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___ReactionAnalysis]:
        """List of Time Analyses for channel combinations."""

    def __init__(
        self,
        *,
        channel_analyses: collections.abc.Iterable[Global___ChannelAnalysis] | None = ...,
        reaction_analyses: collections.abc.Iterable[Global___ReactionAnalysis] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_analyses", b"channel_analyses", "reaction_analyses", b"reaction_analyses"]) -> None: ...

Global___AnalyzeResult: typing_extensions.TypeAlias = AnalyzeResult

@typing.final
class AnalyzeResponse(google.protobuf.message.Message):
    """The top-level message returned to the client by the <code>Analyze</code>
    method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULT_FIELD_NUMBER: builtins.int
    PROCESSED_AUDIO_LENGTH_FIELD_NUMBER: builtins.int
    @property
    def result(self) -> Global___AnalyzeResult:
        """Time Analysis result."""

    @property
    def processed_audio_length(self) -> google.protobuf.duration_pb2.Duration:
        """Total length of the processed audio.
        Set only if this is the last response in the stream.
        """

    def __init__(
        self,
        *,
        result: Global___AnalyzeResult | None = ...,
        processed_audio_length: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["processed_audio_length", b"processed_audio_length", "result", b"result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["processed_audio_length", b"processed_audio_length", "result", b"result"]) -> None: ...

Global___AnalyzeResponse: typing_extensions.TypeAlias = AnalyzeResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2025 Phonexia s.r.o.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Phonexia common message definitions for gRPC API.
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Audio(google.protobuf.message.Message):
    """ Audio message in either raw or one of the standard formats.

     In the case of raw format, this message contains raw audio data that
     are encoded in a format specified in the configuration.
     The audio <code>content</code> is represented as raw audio if the
     <code>raw_audio_config</code> field is specified.

     In case that the <code>raw_audio_config</code> field is not specified,
     this message contains audio data in one of the supported standard formats
     and encodings. Supported formats are <code>WAV</code> (various encodings)
     and <code>FLAC</code>.
     For best results, the audio source should be captured and transmitted
     using a lossless encoding (<code>FLAC</code> or <code>LINEAR16</code>).
     The accuracy of the speech technologies can be reduced if lossy codecs
     are used to capture or transmit audio, particularly if background noise
     is present. Lossy codecs include <code>ALAW</code> or <code>MULAW</code>
     <em>Important: all Phonexia microservices that are audio-based, with the
     exception of <code>MediaNormalization</code> and <code>TimeAnalysis</code>,
     only support mono-channel audio.</em>
     See https://docs.phonexia.com/products/speech-platform-4/microservices/audio-formats
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    TIME_RANGE_FIELD_NUMBER: builtins.int
    RAW_AUDIO_CONFIG_FIELD_NUMBER: builtins.int
    content: builtins.bytes
    """The audio data bytes encoded in the supported format. In case of raw
    audio, this field does not include the audio header, but only the data.
    <em>Note: as with all bytes fields, proto buffers use a pure binary
    representation.</em>
    """
    @property
    def time_range(self) -> Global___TimeRange:
        """Time range of the audio to process. If omitted, the
        whole audio is processed. If <code>start</code> is omitted, the
        audio is processed from the beginning. If <code>end</code> is omitted,
        the audio is processed to the end.
        """

    @property
    def raw_audio_config(self) -> Global___RawAudioConfig:
        """Specify raw audio metadata in case that the <code>content</code> is in
        raw format.
        """

    def __init__(
        self,
        *,
        content: builtins.bytes = ...,
        time_range: Global___TimeRange | None = ...,
        raw_audio_config: Global___RawAudioConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["raw_audio_config", b"raw_audio_config", "time_range", b"time_range"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["content", b"content", "raw_audio_config", b"raw_audio_config", "time_range", b"time_range"]) -> None: ...

Global___Audio: typing_extensions.TypeAlias = Audio

@typing.final
class RawAudioConfig(google.protobuf.message.Message):
    """ Configuration message for raw audio data used in <code>Audio</code> message."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _AudioEncoding:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _AudioEncodingEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[RawAudioConfig._AudioEncoding.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        PCM16: RawAudioConfig._AudioEncoding.ValueType  # 0
        """16-bit signed little-endian linear Pulse Code Modulation"""
        PCM32: RawAudioConfig._AudioEncoding.ValueType  # 1
        """32-bit signed little-endian linear Pulse Code Modulation"""
        MULAW: RawAudioConfig._AudioEncoding.ValueType  # 2
        """μ-law encoding"""
        ALAW: RawAudioConfig._AudioEncoding.ValueType  # 3
        """A-law encoding"""

    class AudioEncoding(_AudioEncoding, metaclass=_AudioEncodingEnumTypeWrapper):
        """Enumeration of supported audio encodings for raw audio data."""

    PCM16: RawAudioConfig.AudioEncoding.ValueType  # 0
    """16-bit signed little-endian linear Pulse Code Modulation"""
    PCM32: RawAudioConfig.AudioEncoding.ValueType  # 1
    """32-bit signed little-endian linear Pulse Code Modulation"""
    MULAW: RawAudioConfig.AudioEncoding.ValueType  # 2
    """μ-law encoding"""
    ALAW: RawAudioConfig.AudioEncoding.ValueType  # 3
    """A-law encoding"""

    ENCODING_FIELD_NUMBER: builtins.int
    SAMPLE_RATE_HERTZ_FIELD_NUMBER: builtins.int
    CHANNELS_FIELD_NUMBER: builtins.int
    encoding: Global___RawAudioConfig.AudioEncoding.ValueType
    """The encoding of the audio data. This field determines how the raw audio
    data is interpreted.
    """
    sample_rate_hertz: builtins.int
    """The sample rate in hertz (Hz) of the audio data. This field specifies
    the number of audio samples per second. Most Phonexia technologies resample
    the audio into 8kHz or 16kHz as a first step.
    """
    channels: builtins.int
    """The number of channels in the audio data.
    <em>Note: if not specified otherwise, technologies only support mono-channel
    audio recordings. Setting this field to values other than 1 will result in an
    error for such technologies.</em>
    """
    def __init__(
        self,
        *,
        encoding: Global___RawAudioConfig.AudioEncoding.ValueType = ...,
        sample_rate_hertz: builtins.int = ...,
        channels: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channels", b"channels", "encoding", b"encoding", "sample_rate_hertz", b"sample_rate_hertz"]) -> None: ...

Global___RawAudioConfig: typing_extensions.TypeAlias = RawAudioConfig

@typing.final
class Voiceprint(google.protobuf.message.Message):
    """Represents the result from voiceprint extraction."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    content: builtins.bytes
    """Voiceprint data bytes in one of the supported formats:
    - UBJSON (Speech Platform 4 native)
    - binary XL5 voiceprint (Speech Engine 3 native)
    """
    def __init__(
        self,
        *,
        content: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["content", b"content"]) -> None: ...

Global___Voiceprint: typing_extensions.TypeAlias = Voiceprint

@typing.final
class Matrix(google.protobuf.message.Message):
    """Data type representing matrix of values. The matrix is represented as a
    linear array in row major format.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROWS_COUNT_FIELD_NUMBER: builtins.int
    COLUMNS_COUNT_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    rows_count: builtins.int
    """Number of rows in the matrix."""
    columns_count: builtins.int
    """Number of columns in the matrix."""
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]:
        """Sequential list of matrix values in row major format."""

    def __init__(
        self,
        *,
        rows_count: builtins.int = ...,
        columns_count: builtins.int = ...,
        values: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["columns_count", b"columns_count", "rows_count", b"rows_count", "values", b"values"]) -> None: ...

Global___Matrix: typing_extensions.TypeAlias = Matrix

@typing.final
class Vector(google.protobuf.message.Message):
    """Data type representing a vector of float values."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUES_FIELD_NUMBER: builtins.int
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]:
        """Sequential list of vector values."""

    def __init__(
        self,
        *,
        values: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["values", b"values"]) -> None: ...

Global___Vector: typing_extensions.TypeAlias = Vector

@typing.final
class TimeRange(google.protobuf.message.Message):
    """Data type representing time range."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_FIELD_NUMBER: builtins.int
    END_FIELD_NUMBER: builtins.int
    @property
    def start(self) -> google.protobuf.duration_pb2.Duration:
        """Start time of the time range."""

    @property
    def end(self) -> google.protobuf.duration_pb2.Duration:
        """End time of the time range."""

    def __init__(
        self,
        *,
        start: google.protobuf.duration_pb2.Duration | None = ...,
        end: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["end", b"end", "start", b"start"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["end", b"end", "start", b"start"]) -> None: ...

Global___TimeRange: typing_extensions.TypeAlias = TimeRange



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/technologies/emotion_recognition/v1/emotion_recognition.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'phonexia/grpc/technologies/emotion_recognition/v1/emotion_recognition.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from phonexia.grpc.common import core_pb2 as phonexia_dot_grpc_dot_common_dot_core__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKphonexia/grpc/technologies/emotion_recognition/v1/emotion_recognition.proto\x12\x31phonexia.grpc.technologies.emotion_recognition.v1\x1a\x1fphonexia/grpc/common/core.proto\x1a\x1egoogle/protobuf/duration.proto\"\xa2\x01\n\x10RecognizeRequest\x12*\n\x05\x61udio\x18\x01 \x01(\x0b\x32\x1b.phonexia.grpc.common.Audio\x12W\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x42.phonexia.grpc.technologies.emotion_recognition.v1.RecognizeConfigH\x00\x88\x01\x01\x42\t\n\x07_config\"C\n\x0fRecognizeConfig\x12\x30\n\rspeech_length\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\"\xa2\x01\n\x11RecognizeResponse\x12R\n\x06result\x18\x01 \x01(\x0b\x32\x42.phonexia.grpc.technologies.emotion_recognition.v1.RecognizeResult\x12\x39\n\x16processed_audio_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"\x94\x01\n\x0fRecognizeResult\x12\x30\n\rspeech_length\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12O\n\x06scores\x18\x02 \x03(\x0b\x32?.phonexia.grpc.technologies.emotion_recognition.v1.EmotionScore\"\xbc\x01\n\x0c\x45motionScore\x12\\\n\x07\x65motion\x18\x01 \x01(\x0e\x32K.phonexia.grpc.technologies.emotion_recognition.v1.EmotionScore.EmotionType\x12\x13\n\x0bprobability\x18\x02 \x01(\x02\"9\n\x0b\x45motionType\x12\t\n\x05\x41NGRY\x10\x00\x12\x07\n\x03SAD\x10\x01\x12\t\n\x05HAPPY\x10\x02\x12\x0b\n\x07NEUTRAL\x10\x03\x32\xaf\x01\n\x12\x45motionRecognition\x12\x98\x01\n\tRecognize\x12\x43.phonexia.grpc.technologies.emotion_recognition.v1.RecognizeRequest\x1a\x44.phonexia.grpc.technologies.emotion_recognition.v1.RecognizeResponse(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.technologies.emotion_recognition.v1.emotion_recognition_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_RECOGNIZEREQUEST']._serialized_start=196
  _globals['_RECOGNIZEREQUEST']._serialized_end=358
  _globals['_RECOGNIZECONFIG']._serialized_start=360
  _globals['_RECOGNIZECONFIG']._serialized_end=427
  _globals['_RECOGNIZERESPONSE']._serialized_start=430
  _globals['_RECOGNIZERESPONSE']._serialized_end=592
  _globals['_RECOGNIZERESULT']._serialized_start=595
  _globals['_RECOGNIZERESULT']._serialized_end=743
  _globals['_EMOTIONSCORE']._serialized_start=746
  _globals['_EMOTIONSCORE']._serialized_end=934
  _globals['_EMOTIONSCORE_EMOTIONTYPE']._serialized_start=877
  _globals['_EMOTIONSCORE_EMOTIONTYPE']._serialized_end=934
  _globals['_EMOTIONRECOGNITION']._serialized_start=937
  _globals['_EMOTIONRECOGNITION']._serialized_end=1112
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/technologies/audio_quality_estimation/v1/audio_quality_estimation.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'phonexia/grpc/technologies/audio_quality_estimation/v1/audio_quality_estimation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from phonexia.grpc.common import core_pb2 as phonexia_dot_grpc_dot_common_dot_core__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nUphonexia/grpc/technologies/audio_quality_estimation/v1/audio_quality_estimation.proto\x12\x36phonexia.grpc.technologies.audio_quality_estimation.v1\x1a\x1fphonexia/grpc/common/core.proto\x1a\x1egoogle/protobuf/duration.proto\"=\n\x0f\x45stimateRequest\x12*\n\x05\x61udio\x18\x01 \x01(\x0b\x32\x1b.phonexia.grpc.common.Audio\"\x90\x03\n\x0e\x45stimateResult\x12\x1c\n\x0fpesq_estimation\x18\x01 \x01(\x02H\x00\x88\x01\x01\x12\x1f\n\x12signal_noise_ratio\x18\x02 \x01(\x02H\x01\x88\x01\x01\x12\x19\n\x0c\x61udio_length\x18\x03 \x01(\x02H\x02\x88\x01\x01\x12\x1a\n\rmax_amplitude\x18\x04 \x01(\x02H\x03\x88\x01\x01\x12\x1a\n\rmin_amplitude\x18\x05 \x01(\x02H\x04\x88\x01\x01\x12\x1b\n\x0epeak_amplitude\x18\x06 \x01(\x02H\x05\x88\x01\x01\x12\x1b\n\x0emean_amplitude\x18\x07 \x01(\x02H\x06\x88\x01\x01\x12\x1a\n\rsampling_rate\x18\x08 \x01(\x05H\x07\x88\x01\x01\x42\x12\n\x10_pesq_estimationB\x15\n\x13_signal_noise_ratioB\x0f\n\r_audio_lengthB\x10\n\x0e_max_amplitudeB\x10\n\x0e_min_amplitudeB\x11\n\x0f_peak_amplitudeB\x11\n\x0f_mean_amplitudeB\x10\n\x0e_sampling_rate\"\xa5\x01\n\x10\x45stimateResponse\x12V\n\x06result\x18\x01 \x01(\x0b\x32\x46.phonexia.grpc.technologies.audio_quality_estimation.v1.EstimateResult\x12\x39\n\x16processed_audio_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration2\xba\x01\n\x16\x41udioQualityEstimation\x12\x9f\x01\n\x08\x45stimate\x12G.phonexia.grpc.technologies.audio_quality_estimation.v1.EstimateRequest\x1aH.phonexia.grpc.technologies.audio_quality_estimation.v1.EstimateResponse(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.technologies.audio_quality_estimation.v1.audio_quality_estimation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ESTIMATEREQUEST']._serialized_start=210
  _globals['_ESTIMATEREQUEST']._serialized_end=271
  _globals['_ESTIMATERESULT']._serialized_start=274
  _globals['_ESTIMATERESULT']._serialized_end=674
  _globals['_ESTIMATERESPONSE']._serialized_start=677
  _globals['_ESTIMATERESPONSE']._serialized_end=842
  _globals['_AUDIOQUALITYESTIMATION']._serialized_start=845
  _globals['_AUDIOQUALITYESTIMATION']._serialized_end=1031
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from phonexia.grpc.technologies.language_identification.v1 import language_identification_pb2 as phonexia_dot_grpc_dot_technologies_dot_language__identification_dot_v1_dot_language__identification__pb2

GRPC_GENERATED_VERSION = '1.76.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in phonexia/grpc/technologies/language_identification/v1/language_identification_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class LanguageIdentificationStub(object):
    """Service implementing language identification.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Identify = channel.stream_unary(
                '/phonexia.grpc.technologies.language_identification.v1.LanguageIdentification/Identify',
                request_serializer=phonexia_dot_grpc_dot_technologies_dot_language__identification_dot_v1_dot_language__identification__pb2.IdentifyRequest.SerializeToString,
                response_deserializer=phonexia_dot_grpc_dot_technologies_dot_language__identification_dot_v1_dot_language__identification__pb2.IdentifyResponse.FromString,
                _registered_method=True)
        self.ListSupportedLanguages = channel.unary_unary(
                '/phonexia.grpc.technologies.language_identification.v1.LanguageIdentification/ListSupportedLanguages',
                request_serializer=phonexia_dot_grpc_dot_technologies_dot_language__identification_dot_v1_dot_language__identification__pb2.ListSupportedLanguagesRequest.SerializeToString,
                response_deserializer=phonexia_dot_grpc_dot_technologies_dot_language__identification_dot_v1_dot_language__identification__pb2.ListSupportedLanguagesResponse.FromString,
                _registered_method=True)
        self.Extract = channel.stream_unary(
                '/phonexia.grpc.technologies.language_identification.v1.LanguageIdentification/Extract',
                request_serializer=phonexia_dot_grpc_dot_technologies_dot_language__identification_dot_v1_dot_language__identification__pb2.ExtractRequest.SerializeToString,
                response_deserializer=phonexia_dot_grpc_dot_technologies_dot_language__identification_dot_v1_dot_language__identification__pb2.ExtractResponse.FromString,
                _registered_method=True)
        self.Adapt = channel.stream_unary(
                '/phonexia.grpc.technologies.language_identification.v1.LanguageIdentification/Adapt',
                request_serializer=phonexia_dot_grpc_dot_technologies_dot_language__identification_dot_v1_dot_language__identification__pb2.AdaptRequest.SerializeToString,
                response_deserializer=phonexia_dot_grpc_dot_technologies_dot_language__identification_dot_v1_dot_language__identification__pb2.AdaptResponse.FromString,
                _registered_method=True)


class LanguageIdentificationServicer(object):
    """Service implementing language identification.
    """

    def Identify(self, request_iterator, context):
        """Performs language identification on the given audio or languageprint.
        Returns list of scores for each built-in or added language.
        Built-in languages are identified by the RFC 5646 language codes.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSupportedLanguages(self, request, context):
        """Retrieve built-in or added languages available to identify in the input.
        This method will return a list of supported languages.
        Built-in languages are identified by the RFC 5646 language codes.
        Languages added via language adaptation are identified by a custom identifier.
        protolint:disable:this MAX_LINE_LENGTH
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Extract(self, request_iterator, context):
        """Performs languageprint extraction on the given audio.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Adapt(self, request_iterator, context):
        """Perform supervised adaptation of the technology using custom-annotated data.
        Individual languages can be adapted for better performance on custom data.
        Alternatively, new languages can be introduced via the adaptation.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_LanguageIdentificationServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Identify': grpc.stream_unary_rpc_method_handler(
                    servicer.Identify,
                    request_deserializer=phonexia_dot_grpc_dot_technologies_dot_language__identification_dot_v1_dot_language__identification__pb2.IdentifyRequest.FromString,
                    response_serializer=phonexia_dot_grpc_dot_technologies_dot_language__identification_dot_v1_dot_language__identification__pb2.IdentifyResponse.SerializeToString,
            ),
            'ListSupportedLanguages': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSupportedLanguages,
                    request_deserializer=phonexia_dot_grpc_dot_technologies_dot_language__identification_dot_v1_dot_language__identification__pb2.ListSupportedLanguagesRequest.FromString,
                    response_serializer=phonexia_dot_grpc_dot_technologies_dot_language__identification_dot_v1_dot_language__identification__pb2.ListSupportedLanguagesResponse.SerializeToString,
            ),
            'Extract': grpc.stream_unary_rpc_method_handler(
                    servicer.Extract,
                    request_deserializer=phonexia_dot_grpc_dot_technologies_dot_language__identification_dot_v1_dot_language__identification__pb2.ExtractRequest.FromString,
                    response_serializer=phonexia_dot_grpc_dot_technologies_dot_language__identification_dot_v1_dot_language__identification__pb2.ExtractResponse.SerializeToString,
            ),
            'Adapt': grpc.stream_unary_rpc_method_handler(
                    servicer.Adapt,
                    request_deserializer=phonexia_dot_grpc_dot_technologies_dot_language__identification_dot_v1_dot_language__identification__pb2.AdaptRequest.FromString,
                    response_serializer=phonexia_dot_grpc_dot_technologies_dot_language__identification_dot_v1_dot_language__identification__pb2.AdaptResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'phonexia.grpc.technologies.language_identification.v1.LanguageIdentification', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('phonexia.grpc.technologies.language_identification.v1.LanguageIdentification', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class LanguageIdentification(object):
    """Service implementing language identification.
    """

    @staticmethod
    def Identify(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(
            request_iterator,
            target,
            '/phonexia.grpc.technologies.language_identification.v1.LanguageIdentification/Identify',
            phonexia_dot_grpc_dot_technologies_dot_language__identification_dot_v1_dot_language__identification__pb2.IdentifyRequest.SerializeToString,
            phonexia_dot_grpc_dot_technologies_dot_language__identification_dot_v1_dot_language__identification__pb2.IdentifyResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListSupportedLanguages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/phonexia.grpc.technologies.language_identification.v1.LanguageIdentification/ListSupportedLanguages',
            phonexia_dot_grpc_dot_technologies_dot_language__identification_dot_v1_dot_language__identification__pb2.ListSupportedLanguagesRequest.SerializeToString,
            phonexia_dot_grpc_dot_technologies_dot_language__identification_dot_v1_dot_language__identification__pb2.ListSupportedLanguagesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Extract(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(
            request_iterator,
            target,
            '/phonexia.grpc.technologies.language_identification.v1.LanguageIdentification/Extract',
            phonexia_dot_grpc_dot_technologies_dot_language__identification_dot_v1_dot_language__identification__pb2.ExtractRequest.SerializeToString,
            phonexia_dot_grpc_dot_technologies_dot_language__identification_dot_v1_dot_language__identification__pb2.ExtractResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Adapt(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(
            request_iterator,
            target,
            '/phonexia.grpc.technologies.language_identification.v1.LanguageIdentification/Adapt',
            phonexia_dot_grpc_dot_technologies_dot_language__identification_dot_v1_dot_language__identification__pb2.AdaptRequest.SerializeToString,
            phonexia_dot_grpc_dot_technologies_dot_language__identification_dot_v1_dot_language__identification__pb2.AdaptResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from phonexia.grpc.technologies.keyword_spotting.v1 import keyword_spotting_pb2 as phonexia_dot_grpc_dot_technologies_dot_keyword__spotting_dot_v1_dot_keyword__spotting__pb2

GRPC_GENERATED_VERSION = '1.76.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in phonexia/grpc/technologies/keyword_spotting/v1/keyword_spotting_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class KeywordSpottingStub(object):
    """*
    Service implementing Keyword Spotting. For more information, see
    https://docs.cloud.phonexia.com/products/speech-platform-4/technologies/keyword-spotting/
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Detect = channel.stream_stream(
                '/phonexia.grpc.technologies.keyword_spotting.v1.KeywordSpotting/Detect',
                request_serializer=phonexia_dot_grpc_dot_technologies_dot_keyword__spotting_dot_v1_dot_keyword__spotting__pb2.DetectRequest.SerializeToString,
                response_deserializer=phonexia_dot_grpc_dot_technologies_dot_keyword__spotting_dot_v1_dot_keyword__spotting__pb2.DetectResponse.FromString,
                _registered_method=True)
        self.ListAllowedSymbols = channel.unary_unary(
                '/phonexia.grpc.technologies.keyword_spotting.v1.KeywordSpotting/ListAllowedSymbols',
                request_serializer=phonexia_dot_grpc_dot_technologies_dot_keyword__spotting_dot_v1_dot_keyword__spotting__pb2.ListAllowedSymbolsRequest.SerializeToString,
                response_deserializer=phonexia_dot_grpc_dot_technologies_dot_keyword__spotting_dot_v1_dot_keyword__spotting__pb2.ListAllowedSymbolsResponse.FromString,
                _registered_method=True)


class KeywordSpottingServicer(object):
    """*
    Service implementing Keyword Spotting. For more information, see
    https://docs.cloud.phonexia.com/products/speech-platform-4/technologies/keyword-spotting/
    """

    def Detect(self, request_iterator, context):
        """*
        Detect performs keyword spotting on the audio data.
        Returns detected keywords and their pronunciations.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAllowedSymbols(self, request, context):
        """*
        ListAllowedSymbols returns lists of allowed symbols for the keyword
        spotting model.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_KeywordSpottingServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Detect': grpc.stream_stream_rpc_method_handler(
                    servicer.Detect,
                    request_deserializer=phonexia_dot_grpc_dot_technologies_dot_keyword__spotting_dot_v1_dot_keyword__spotting__pb2.DetectRequest.FromString,
                    response_serializer=phonexia_dot_grpc_dot_technologies_dot_keyword__spotting_dot_v1_dot_keyword__spotting__pb2.DetectResponse.SerializeToString,
            ),
            'ListAllowedSymbols': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAllowedSymbols,
                    request_deserializer=phonexia_dot_grpc_dot_technologies_dot_keyword__spotting_dot_v1_dot_keyword__spotting__pb2.ListAllowedSymbolsRequest.FromString,
                    response_serializer=phonexia_dot_grpc_dot_technologies_dot_keyword__spotting_dot_v1_dot_keyword__spotting__pb2.ListAllowedSymbolsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'phonexia.grpc.technologies.keyword_spotting.v1.KeywordSpotting', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('phonexia.grpc.technologies.keyword_spotting.v1.KeywordSpotting', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class KeywordSpotting(object):
    """*
    Service implementing Keyword Spotting. For more information, see
    https://docs.cloud.phonexia.com/products/speech-platform-4/technologies/keyword-spotting/
    """

    @staticmethod
    def Detect(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(
            request_iterator,
            target,
            '/phonexia.grpc.technologies.keyword_spotting.v1.KeywordSpotting/Detect',
            phonexia_dot_grpc_dot_technologies_dot_keyword__spotting_dot_v1_dot_keyword__spotting__pb2.DetectRequest.SerializeToString,
            phonexia_dot_grpc_dot_technologies_dot_keyword__spotting_dot_v1_dot_keyword__spotting__pb2.DetectResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListAllowedSymbols(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/phonexia.grpc.technologies.keyword_spotting.v1.KeywordSpotting/ListAllowedSymbols',
            phonexia_dot_grpc_dot_technologies_dot_keyword__spotting_dot_v1_dot_keyword__spotting__pb2.ListAllowedSymbolsRequest.SerializeToString,
            phonexia_dot_grpc_dot_technologies_dot_keyword__spotting_dot_v1_dot_keyword__spotting__pb2.ListAllowedSymbolsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/technologies/transcription_normalization/v1/transcription_normalization.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'phonexia/grpc/technologies/transcription_normalization/v1/transcription_normalization.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n[phonexia/grpc/technologies/transcription_normalization/v1/transcription_normalization.proto\x12\x39phonexia.grpc.technologies.transcription_normalization.v1\x1a\x1egoogle/protobuf/duration.proto\"\xd4\x01\n\x10NormalizeRequest\x12T\n\x08segments\x18\x01 \x03(\x0b\x32\x42.phonexia.grpc.technologies.transcription_normalization.v1.Segment\x12_\n\x06\x63onfig\x18\x02 \x01(\x0b\x32J.phonexia.grpc.technologies.transcription_normalization.v1.NormalizeConfigH\x00\x88\x01\x01\x42\t\n\x07_config\"5\n\x0fNormalizeConfig\x12\x15\n\x08language\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_language\"i\n\x11NormalizeResponse\x12T\n\x08segments\x18\x01 \x03(\x0b\x32\x42.phonexia.grpc.technologies.transcription_normalization.v1.Segment\"\x89\x01\n\x04Word\x12\x0c\n\x04text\x18\x01 \x01(\t\x12-\n\nstart_time\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x17\n\x0fpunctuated_text\x18\x04 \x01(\t\"\xc3\x01\n\x07Segment\x12\x0c\n\x04text\x18\x01 \x01(\t\x12-\n\nstart_time\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12N\n\x05words\x18\x04 \x03(\x0b\x32?.phonexia.grpc.technologies.transcription_normalization.v1.Word2\xc9\x01\n\x1aTranscriptionNormalization\x12\xaa\x01\n\tNormalize\x12K.phonexia.grpc.technologies.transcription_normalization.v1.NormalizeRequest\x1aL.phonexia.grpc.technologies.transcription_normalization.v1.NormalizeResponse(\x01\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.technologies.transcription_normalization.v1.transcription_normalization_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_NORMALIZEREQUEST']._serialized_start=187
  _globals['_NORMALIZEREQUEST']._serialized_end=399
  _globals['_NORMALIZECONFIG']._serialized_start=401
  _globals['_NORMALIZECONFIG']._serialized_end=454
  _globals['_NORMALIZERESPONSE']._serialized_start=456
  _globals['_NORMALIZERESPONSE']._serialized_end=561
  _globals['_WORD']._serialized_start=564
  _globals['_WORD']._serialized_end=701
  _globals['_SEGMENT']._serialized_start=704
  _globals['_SEGMENT']._serialized_end=899
  _globals['_TRANSCRIPTIONNORMALIZATION']._serialized_start=902
  _globals['_TRANSCRIPTIONNORMALIZATION']._serialized_end=1103
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2025 Phonexia s.r.o.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Phonexia Gender Identification gRPC API.
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import phonexia.grpc.common.core_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class IdentifyRequest(google.protobuf.message.Message):
    """The top-level message sent by the client for the <code>Identify</code>
    method.
    The method accepts either audio data or voiceprints.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VOICEPRINTS_FIELD_NUMBER: builtins.int
    AUDIO_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    @property
    def voiceprints(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[phonexia.grpc.common.core_pb2.Voiceprint]:
        """List of voiceprints for the identification."""

    @property
    def audio(self) -> phonexia.grpc.common.core_pb2.Audio:
        """Audio data in which gender is to be identified. There is no minimum audio length limit."""

    @property
    def config(self) -> Global___IdentifyConfig:
        """Configuration for the gender identification."""

    def __init__(
        self,
        *,
        voiceprints: collections.abc.Iterable[phonexia.grpc.common.core_pb2.Voiceprint] | None = ...,
        audio: phonexia.grpc.common.core_pb2.Audio | None = ...,
        config: Global___IdentifyConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["audio", b"audio", "config", b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["audio", b"audio", "config", b"config", "voiceprints", b"voiceprints"]) -> None: ...

Global___IdentifyRequest: typing_extensions.TypeAlias = IdentifyRequest

@typing.final
class IdentifyConfig(google.protobuf.message.Message):
    """Message used for configuration of the <code>Identify</code> method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEECH_LENGTH_FIELD_NUMBER: builtins.int
    @property
    def speech_length(self) -> google.protobuf.duration_pb2.Duration:
        """Specifies the maximum speech length from which the gender will be identified.
        If there is less speech in the audio than the specified duration, the gender
        will be identified from the entire audio. This option is applicable only for Audio
        data.
        """

    def __init__(
        self,
        *,
        speech_length: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["speech_length", b"speech_length"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["speech_length", b"speech_length"]) -> None: ...

Global___IdentifyConfig: typing_extensions.TypeAlias = IdentifyConfig

@typing.final
class Score(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCORE_LLR_FIELD_NUMBER: builtins.int
    PROBABILITY_FIELD_NUMBER: builtins.int
    score_llr: builtins.float
    """Log-likelihood ratio score. The LLR provides a quantitative measure of
    how much more likely the data is under one model (gender) compared
    to another.
    A positive LLR suggests that the respective model is more likely to be
    supported by the data than the other model, while the negative LLR suggests
    the opposite.
    """
    probability: builtins.float
    """Decimal value between 0.0 and 1.0, representing a probability."""
    def __init__(
        self,
        *,
        score_llr: builtins.float = ...,
        probability: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["probability", b"probability", "score_llr", b"score_llr"]) -> None: ...

Global___Score: typing_extensions.TypeAlias = Score

@typing.final
class IdentifyResult(google.protobuf.message.Message):
    """A gender identification result. It contains scores for respective genders."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCORE_MALE_FIELD_NUMBER: builtins.int
    SCORE_FEMALE_FIELD_NUMBER: builtins.int
    SPEECH_LENGTH_FIELD_NUMBER: builtins.int
    @property
    def score_male(self) -> Global___Score:
        """Score for male. Not set if file is empty or doesn't contain enough speech."""

    @property
    def score_female(self) -> Global___Score:
        """Score for female. Not set if file is empty or doesn't contain enough speech."""

    @property
    def speech_length(self) -> google.protobuf.duration_pb2.Duration:
        """Total speech length from which the gender were recognized."""

    def __init__(
        self,
        *,
        score_male: Global___Score | None = ...,
        score_female: Global___Score | None = ...,
        speech_length: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_score_female", b"_score_female", "_score_male", b"_score_male", "score_female", b"score_female", "score_male", b"score_male", "speech_length", b"speech_length"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_score_female", b"_score_female", "_score_male", b"_score_male", "score_female", b"score_female", "score_male", b"score_male", "speech_length", b"speech_length"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_score_female", b"_score_female"]) -> typing.Literal["score_female"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_score_male", b"_score_male"]) -> typing.Literal["score_male"] | None: ...

Global___IdentifyResult: typing_extensions.TypeAlias = IdentifyResult

@typing.final
class IdentifyResponse(google.protobuf.message.Message):
    """The top-level message returned to the client by the <code>Identify</code>
    method. It contains the result as one or more <code>IdentifyResult</code>
    messages.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULTS_FIELD_NUMBER: builtins.int
    PROCESSED_AUDIO_LENGTH_FIELD_NUMBER: builtins.int
    @property
    def results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___IdentifyResult]:
        """Sequential list of results corresponding to sequential list of voiceprints
        in <code>IdentifyRequest</code>. Contains single result when using audio.
        """

    @property
    def processed_audio_length(self) -> google.protobuf.duration_pb2.Duration:
        """When available, total length of the processed audio.
        Set only if audio is used in <code>IdentifyRequest</code>.
        """

    def __init__(
        self,
        *,
        results: collections.abc.Iterable[Global___IdentifyResult] | None = ...,
        processed_audio_length: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["processed_audio_length", b"processed_audio_length"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["processed_audio_length", b"processed_audio_length", "results", b"results"]) -> None: ...

Global___IdentifyResponse: typing_extensions.TypeAlias = IdentifyResponse
